Module box_component
photon_
ui
0.2.0
Module box_
component
Module Items
Structs
In photon_
ui::
components
photon_ui
::
components
Module
box_
component
A box that draws a border around its content.
Structs

Box
A rectangular box filled with spaces, optionally with a background color.