Breadcrumbs

Struct Breadcrumbs 

pub struct Breadcrumbs { /* private fields */ }
A non-interactive breadcrumbs trail.

Renders as Home > Settings > Account where the last item is bold and uses the primary text color, earlier items use the secondary text color, and the separator uses the default border color.

Implementations

Source

impl Breadcrumbs

pub fn new(items: Vec<impl Into<String>>) -> Self

Create a new breadcrumbs component with the given items.

pub fn separator(self, sep: impl Into<String>) -> Self

Set a custom separator (default is " > ").