Container

Struct Container 

pub struct Container { /* private fields */ }
A component that lays out its children using a Layout.

Each child is rendered into the rect assigned by the layout via render_rect.

Implementations

Source

impl Container

pub fn new(layout: Layout) -> Self

Create a new container with the given layout.

pub fn push(&mut self, child: Box<dyn Component>)

Add a child component.

pub fn with_child(self, child: Box<dyn Component>) -> Self

Builder-style add.