pub struct StatusBar { /* private fields */ }Expand description
A non-interactive status bar with three alignment zones.
Segments in the left zone are rendered at the left edge, center
segments are centered, and right segments are at the right edge.
Multiple segments within the same zone are joined with two spaces.
Implementations