Module table

Module table 

Table with sortable columns and row selection.

Structs

Column
A column definition for the Table component.
Row
A single row of data in the Table component.
Table
A table component with sortable columns, row selection, and interactive filtering.