pub struct TruncatedText { /* private fields */ }Expand description
Static text that is truncated with an ellipsis if it exceeds the available width.
Each line is padded with pad_x spaces and truncated independently.
pad_y empty lines are added before and after the content.
Implementations