Key

Enum Key 

pub enum Key {
    Char(char, Modifiers),
    Code(KeyCode, Modifiers),
}
A portable representation of a key press with modifier state.

Unlike raw crossterm KeyEvent, this type is Hash and Eq, making it suitable for use in maps such as KeybindingsManager.

Variants



Char(char, Modifiers)

A printable character with modifiers.



Code(KeyCode, Modifiers)

A special key code with modifiers.

Implementations

Source

impl Key

pub fn enter() -> Self

Enter / Return with no modifiers.

pub fn left() -> Self

Left arrow with no modifiers.

pub fn right() -> Self

Right arrow with no modifiers.

pub fn up() -> Self

Up arrow with no modifiers.

pub fn down() -> Self

Down arrow with no modifiers.

pub fn backspace() -> Self

Backspace with no modifiers.

pub fn delete() -> Self

Delete with no modifiers.

pub fn home() -> Self

Home with no modifiers.

pub fn end() -> Self

End with no modifiers.

pub fn tab() -> Self

Tab with no modifiers.

pub fn esc() -> Self

Escape with no modifiers.

pub fn ctrl(c: char) -> Self

Character with Control held.

pub fn ctrl_shift(c: char) -> Self

Character with Control + Shift held.

pub fn alt(c: char) -> Self

Character with Alt held.

pub fn char(c: char) -> Self

Character with no modifiers.