Module layer
photon_
ui
0.4.5
Module layer
Module Items
Structs
Enums
In crate photon_
ui
photon_ui
Module
layer
Full-terminal-size stacking surfaces.
Structs

Layer
A full-terminal-size surface that holds its own components and layout.
Enums

Layer
Kind
Classification of a layer for backward-compatible TUI APIs.
Shadow
Visual effect applied to lower layers to make stacking obvious.