Module border

Module border 

Border drawing primitives. Border drawing primitives for terminal UIs.

Provides Border — a set of characters for drawing rectangular outlines — and draw_border for rendering them into a Rendered buffer with ANSI styling.

Structs

Border
Characters used to draw a rectangular border.

Functions

draw_border
Draw a border into target within the given rect.