pub struct Layout { /* private fields */ }Expand description
A layout configuration that splits a Rect into sub-rects.
Implementations
Sourceimpl Layout
impl Layout
Sourcepub fn new<I>(direction: Direction, constraints: I) -> Self
pub fn new<I>(direction: Direction, constraints: I) -> Self
Create a new layout with the given direction and constraints.
Sourcepub fn vertical<I>(constraints: I) -> Self
pub fn vertical<I>(constraints: I) -> Self
Shorthand for Layout::new with Direction::Vertical.
Sourcepub fn horizontal<I>(constraints: I) -> Self
pub fn horizontal<I>(constraints: I) -> Self
Shorthand for Layout::new with Direction::Horizontal.
Sourcepub fn constraints<I>(self, constraints: I) -> Self
pub fn constraints<I>(self, constraints: I) -> Self
Replace the current constraints.
Sourcepub fn horizontal_margin(self, margin: u16) -> Self
pub fn horizontal_margin(self, margin: u16) -> Self
Set horizontal margin (left and right).
Sourcepub fn vertical_margin(self, margin: u16) -> Self
pub fn vertical_margin(self, margin: u16) -> Self
Set vertical margin (top and bottom).