Module renderer

Module renderer 

Differential terminal renderer.

Structs

ImageCommand
A command to display an image in the terminal.
Rendered
The output of a component’s render call.
Renderer
Differential terminal renderer.

Enums

InputResult
Result of handling an input event.
RenderError
Error type returned when a component produces invalid output.
RenderStrategy
Strategy used by Renderer to draw a frame.