ImageCommand

Struct ImageCommand 

pub struct ImageCommand {
    pub id: u32,
    pub data: String,
    pub row: u16,
    pub col: u16,
}
A command to display an image in the terminal.

Images are identified by an id so the renderer can track which images are still visible and delete stale ones. row and col are the screen cell where the terminal should place the top-left corner of the image.

Fields

id: u32

Unique identifier for this image.

data: String

Raw image data or protocol-specific payload.

row: u16

Target row (0-indexed) for the top-left corner of the image.

col: u16

Target column (0-indexed) for the top-left corner of the image.