pub struct Container { /* private fields */ }Expand description
A component that lays out its children using a Layout.
Each child is rendered into the rect assigned by the layout via
render_rect.
Implementations