StatusBar

Struct StatusBar 

pub struct StatusBar { /* private fields */ }
A non-interactive status bar with three alignment zones.

Segments in the left zone are rendered at the left edge, center segments are centered, and right segments are at the right edge. Multiple segments within the same zone are joined with two spaces.

Implementations

Source

impl StatusBar

pub fn new() -> Self

Create an empty status bar.

pub fn left(self, segment: Segment) -> Self

Add a segment to the left zone.

pub fn center(self, segment: Segment) -> Self

Add a segment to the center zone.

pub fn right(self, segment: Segment) -> Self

Add a segment to the right zone.