pub struct ImageCommand {
pub id: u32,
pub data: String,
}Expand description
A command to display an image in the terminal.
Images are identified by an id so the renderer can track which images
are still visible and delete stale ones.
Fields
id: u32Unique identifier for this image.
data: StringRaw image data or protocol-specific payload.